{% extends "shopyo_base/main_base.html" %}

{% set active_page = "reset_password" %}
{% block pagehead %}
	<title>Reset Password</title>
{% endblock %}
{% block content %}

	<div class="container col-md-6 off-set-2 text-center">
        <div class="card">
            <div class="card-body">
                <img src="/static/shopyo.svg" width="175" height="150">
                <p class="h2">Reset Password</p>
                <form action="" method="POST">
                    <div class="input-group mb-3">
                        <div class="input-group-prepend">
                            <span class="input-group-text"><i class="fa fa-key"></i></span>
                        </div>
                        {{ form.password(placeholder="New Password") }}
                        {% if form.password.errors %}
                            <ul class="errors">
                                {% for error in form.password.errors %}
                                    <li>{{ error }}</li>
                                {% endfor %}
                            </ul>
                        {% endif %}
                    </div>
                    <div class="input-group mb-3">
                        <div class="input-group-prepend">
                            <span class="input-group-text"><i class="fa fa-key"></i></span>
                        </div>
                        {{ form.confirm(placeholder="Repeat Password") }}
                        {% if form.confirm.errors %}
                            <ul class="errors">
                                {% for error in form.confirm.errors %}
                                    <li>{{ error }}</li>
                                {% endfor %}
                            </ul>
                        {% endif %}
                    </div>
                    <input type="hidden" name="csrf_token" value="{{ csrf_token() }}"/>
                    <input type="submit" name="" value="Reset Password" class="btn btn-info">
                </form>
            </div>
        </div>
    </div>

{% endblock %}
