<p>Dear {{ user.email }},</p>

<p>To reset your password <a href="{{ url_for('shopyo_auth.reset_password', token=token, _external=True) }}">click here</a>.</p>

<p>Alternatively, you can paste the following link in your browser's address bar:</p>
<p>{{ url_for('shopyo_auth.reset_password', token=token, _external=True) }}</p>

<p>If you have not requested a password reset simply ignore this email.</p>

<p>Sincerely,</p>

<p>The Shopyo Team</p>
