{% extends "shopyo_base/main_base.html" %}

{% set active_page = "forgot_password" %}
{% block pagehead %}
	<title>Forgot Password</title>
{% endblock %}
{% block content %}

	<div class="container col-md-6 off-set-2 text-center">
        <div class="card">
            <div class="card-body">
                <img src="/static/shopyo.svg" width="175" height="150">
                <p class="h2">Forgot Password</p>
                <form action="{{url_for('shopyo_auth.forgot_password')}}" method="POST">
                    <div class="input-group mb-3">
                        <div class="input-group-prepend">
                            <span class="input-group-text"><i class="fa fa-envelope"></i></span>
                        </div>
                        {{ form.email() }}
                        {% if form.email.errors %}
                            <ul class="errors">
                                {% for error in form.email.errors %}
                                    <li>{{ error }}</li>
                                {% endfor %}
                            </ul>
                        {% endif %}
                    </div>
                    <input type="hidden" name="csrf_token" value="{{ csrf_token() }}"/>
                    <input type="submit" name="" value="Submit" class="btn btn-info">
                </form>
            </div>
        </div>
    </div>

{% endblock %}
